==> haskell-mutable-containers-0.3.4.1-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-1ZUNWdVUjAjHFpRNM4ADom
key:                  mutable-containers-0.3.4.1-1ZUNWdVUjAjHFpRNM4ADom
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  2593338a7d03331d3daaace1e65ba577
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-1ZUNWdVUjAjHFpRNM4ADom
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    mono-traversable-1.0.20.0-CzEJ22bNbclFtLiWrkT3zG
    primitive-0.7.4.0-HNczdIKRRGYAqYHurkpkro
    vector-0.13.1.0-Il4qKxVtRccCcBZCzPMWy6

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mutable-containers-0.3.4.1-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-6InKvprGW3HD49O2kIHX77
key:                  mutable-containers-0.3.4.1-6InKvprGW3HD49O2kIHX77
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  07590d13f5df04267507932714cb2e44
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-6InKvprGW3HD49O2kIHX77
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    mono-traversable-1.0.21.0-LKQUfLFEL50DmNOAVS2uOg
    primitive-0.7.4.0-HNczdIKRRGYAqYHurkpkro
    vector-0.13.1.0-Il4qKxVtRccCcBZCzPMWy6

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
